@@ -12,10 +12,18 @@ def strip_leading_double_space(stream):
     return stream.replace("\n  ", "\n")
 
 
-with open('discord_ids.json') as h:
-    ids = json.loads(h.read())
+with open('../aoe2-events/safe') as h:
+    #ids = json.loads(h.read())
     with open('data/players.yaml') as h2:
         players = yaml.load(h2)
+        lines = h.readlines()
+        for player in players:
+            for line in lines:
+                p = line.strip().split(" ")
+                if p[1].strip() == player['name']:
+                    print(p[1], p[2])
+                    player['discord_id'] = p[2].strip()
+    """
         for discord_id in ids:
             for p in players:
                 nicks = [p['name']]
@@ -28,5 +36,6 @@ with open('discord_ids.json') as h:
                     if helpers.same(discord_id.split('#')[0], n):
                         print(discord_id, '->', p['name'])
                         p['discord_id'] = discord_id
+    """
     with open('data/players.yaml', 'w') as handle:
         yaml.dump(players, handle, transform=strip_leading_double_space)
